==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/RedactType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;You can use the redact operation element to redact the contents of a document and remove metadata.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for RedactType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="RedactType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseToolboxType">
 *       <all>
 *         <element name="sanitize" type="{http://schema.webpdf.de/1.0/operation}SanitizeType" minOccurs="0"/>
 *         <element name="blacken" type="{http://schema.webpdf.de/1.0/operation}BlackenType" minOccurs="0"/>
 *       </all>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RedactType", propOrder = {
    "sanitize",
    "blacken"
})
public class RedactType
    extends BaseToolboxType
{

    protected SanitizeType sanitize;
    protected BlackenType blacken;

    /**
     * Gets the value of the sanitize property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeType }
     *     
     */
    public SanitizeType getSanitize() {
        return sanitize;
    }

    /**
     * Sets the value of the sanitize property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeType }
     *     
     */
    public void setSanitize(SanitizeType value) {
        this.sanitize = value;
    }

    public boolean isSetSanitize() {
        return (this.sanitize!= null);
    }

    /**
     * Gets the value of the blacken property.
     * 
     * @return
     *     possible object is
     *     {@link BlackenType }
     *     
     */
    public BlackenType getBlacken() {
        return blacken;
    }

    /**
     * Sets the value of the blacken property.
     * 
     * @param value
     *     allowed object is
     *     {@link BlackenType }
     *     
     */
    public void setBlacken(BlackenType value) {
        this.blacken = value;
    }

    public boolean isSetBlacken() {
        return (this.blacken!= null);
    }

}

==> webpdf-wsclient-10.0.2-sources.jar: net/webpdf/wsclient/schema/operation/RedactType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;You can use the redact operation element to redact the contents of a document and remove metadata.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for RedactType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="RedactType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseToolboxType">
 *       <all>
 *         <element name="sanitize" type="{http://schema.webpdf.de/1.0/operation}SanitizeType" minOccurs="0"/>
 *         <element name="blacken" type="{http://schema.webpdf.de/1.0/operation}BlackenType" minOccurs="0"/>
 *       </all>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RedactType", propOrder = {
    "sanitize",
    "blacken"
})
public class RedactType
    extends BaseToolboxType
{

    protected SanitizeType sanitize;
    protected BlackenType blacken;

    /**
     * Gets the value of the sanitize property.
     * 
     * @return
     *     possible object is
     *     {@link SanitizeType }
     *     
     */
    public SanitizeType getSanitize() {
        return sanitize;
    }

    /**
     * Sets the value of the sanitize property.
     * 
     * @param value
     *     allowed object is
     *     {@link SanitizeType }
     *     
     */
    public void setSanitize(SanitizeType value) {
        this.sanitize = value;
    }

    public boolean isSetSanitize() {
        return (this.sanitize!= null);
    }

    /**
     * Gets the value of the blacken property.
     * 
     * @return
     *     possible object is
     *     {@link BlackenType }
     *     
     */
    public BlackenType getBlacken() {
        return blacken;
    }

    /**
     * Sets the value of the blacken property.
     * 
     * @param value
     *     allowed object is
     *     {@link BlackenType }
     *     
     */
    public void setBlacken(BlackenType value) {
        this.blacken = value;
    }

    public boolean isSetBlacken() {
        return (this.blacken!= null);
    }

}
